import { Injectable, Optional, Inject } from '@angular/core';
import { JwtHelperService } from '@auth0/angular-jwt';
import { HttpService } from './http.service';
import { tap, catchError, map } from 'rxjs/operators';
import { Router } from '@angular/router';
import { of } from 'rxjs';

export class Tokens {
    token: string;
    refreshToken: string;
}


@Injectable({
    providedIn: 'root'
})
export class AuthService {
    private JWT_TOKEN = "jwtToken";
    private REFRESH_TOKEN = "refreshToken";

    constructor(
        public jwtHelper: JwtHelperService,
        public router: Router,
        @Optional() public http: HttpService
    ) {
    }

    public isAuthenticated(): boolean {

        const token = this.getJwtToken();

        // Check whether the token is expired and return
        // true or false
        return token && !this.jwtHelper.isTokenExpired(token);
    }

    public refreshToken() {
        let token = this.getJwtToken();
        let refreshToken = this.getRefreshToken();
        return this.http.RefreshToken(token, refreshToken)
            .pipe(
                tap((tokens: Tokens) => {
                    this.storeTokens(tokens);
                }),
                catchError(e => {
                    if (e.status === 406) {
                        this.clearToken();
                        this.router.navigate(["/login"])
                    }

                    return of(null)
                })
            )
    }


    public checkToken() {
        let token = this.getJwtToken();
        let refreshToken = this.getRefreshToken();
        return this.http.CheckToken(token, refreshToken)
            .pipe(
                map(() => true),
                catchError(e => {
                    return of(false)
                })
            )
    }

    public getJwtToken() {
        return localStorage.getItem("jwtToken");
    }

    private getRefreshToken() {
        return localStorage.getItem("refreshToken")
    }

    public clearToken() {
        localStorage.clear();
    }

    public storeTokens(tokens: Tokens) {
        if (tokens) {
            localStorage.setItem(this.JWT_TOKEN, tokens.token);
            localStorage.setItem(this.REFRESH_TOKEN, tokens.refreshToken);
        }
    }
}