import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, Resolve } from '@angular/router';
import { HttpService } from './http.service';
import { catchError, map } from 'rxjs/operators';
import { of, Observable } from 'rxjs';

export interface FormRole {
    INS: string;
    CHG: string;
    DEL: string;
    INQ: string;
}

@Injectable()
export class RoleResolver implements Resolve<FormRole> {
    constructor(
        private http: HttpService,
    ) { }

    resolve(snapshot: ActivatedRouteSnapshot): Observable<FormRole> {
        let formId = snapshot.url[0].path;
        let roleDetail: FormRole = {
            INS: "N",
            CHG: "N",
            DEL: "N",
            INQ: "N"
        }

        return this.http.GetFormRole(formId)
            .pipe(
                map((response: FormRole) => {
                    return response
                }),
                catchError(error => of(roleDetail))
            )
    }
}
