import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';
import * as moment from 'moment';

@Component({
  selector: 'SNPP104_NP',
  templateUrl: './SNPP104_NP.component.html',
  styleUrls: ['./SNPP104_NP.component.css']
})

export class SNPP104_NPComponent implements OnInit {
  constructor(
    protected http: HttpService,
    protected global: Globals,
    protected modal: ModalService,
    protected viewref: ViewContainerRef
  ) { }

  public showUpload: boolean = false;
  public showDetail: boolean = false;
  public HeaderList: Array<any> = [];
  public HeaderDetail: any = {};
  public params: any = {};

  ngOnInit() { }

  SearchList(params) {
    this.params = params;
    this.HeaderList = [];
    this.http.post("AC", "SNPP104_NP_List", {
      PROCESS_DATE: params.ProcessDate && this.global.ConvertDateToFormatSTD(params.ProcessDate),
      STATUS_CODE: params.Status
    }).subscribe(result => {
      this.HeaderList = result.Table;
    }, err => {
      console.error(err);
    })
  }

  ShowDetail(data) {
    this.HeaderDetail = data;
    this.showDetail = true;
  }

  DeleteDetail(data) {
    if (data.STATUS_CODE == '1') {
      this.modal.confirm("Are you sure to delete this record?", this.viewref
        , () => {
          this.http.post("AC", "SNPP104_NP_Delete", {
            PROCESS_DATE: this.global.ConvertDateToFormatSTD(data.PROCESS_DATE)
          }).subscribe(result => {
            if(result.status === "Done") {
              this.modal.info("Deleted successfully.", this.viewref, () => {
                this.SearchList(this.params);
              })
            } else {
              this.modal.error(result.message, this.viewref)
            }
          }, err => {
            console.error(err);
          })
        }, () => { })
    } else {
      this.modal.warning("Only New can be deleted.", this.viewref);
    }
  }

  UploadCallBack(st: boolean) {
    if(st) {
      this.SearchList(this.params);
    }
  }

  OnShowDetailChange(value: boolean) {
    this.showDetail = value;
    //Close detail
    if(!value) {
      this.SearchList(this.params);
    }
  }
}
