import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';
import * as moment from 'moment';

@Component({
  selector: 'snm017p',
  templateUrl: './SNM017P.component.html',
  styleUrls: ['./SNM017P.component.css']
})

export class SNM017PComponent implements OnInit {

  public params: any = {};

  public Data: any = {
    COMPANY_CODE: null,
    EFFECTIVE_DATE: null,
    CUSTOMER_CODE: null,
    CUSTOMER_NAME: null,
    PART_NO: null,
    PART_NAME: null,
    CURRENCY_CODE: null,
    CURRENCY_NAME: null,
    NET_PRICE: null,
    FORMER_NET: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    LAST_IP_ADDR: null,
    LAST_UPD_PGM: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    LAST_UPD_NAME: null
  };

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals,
    private viewRef: ViewContainerRef
  ) { }

  @ViewChild("dialogMain", { static: false }) dialogMain: any;
  @ViewChild("dialogReport", { static: false }) dialogReport: any;

  public MainDatatable: any = [];
  public FrmTitle: any;
  public IsEdit: any = true;

  ngOnInit() {
    this.InitData();
    this.params.EFFECTIVE_DATE = new Date();
    this.params.EFFECTIVE_DATE_S = new Date();
    this.params.EFFECTIVE_DATE_E = new Date();
  }

  SearchExportPrice = () => {
    this.http.post('AC', 'SNM017P_GetExport_Price', this.params)
      .subscribe(res => {
        this.MainDatatable = res.Table;
      })
  }

  DateChange() {
    this.params.CUSTOMER_CODE = null;
    this.params.PART_NO = null;
    this.params.CURRENCY_CODE = null;
  }

  InitData() {
    this.Data = {};
  }

  CreateClick() {
    this.FrmTitle = "New Export Price";
    this.IsEdit = false;
    this.InitData();
    this.Data.EFFECTIVE_DATE = new Date();
    this.dialogMain.OpenDialog();
  }

  EditClick(row) {
    this.FrmTitle = "Edit Export Price";
    this.IsEdit = true;
    this.InitData();
    this.Data = row;
    this.dialogMain.OpenDialog();
  }

  ConfirmDelete(row) {
    this.InitData();
    this.Data = row;
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.Delete);
  }

  Delete = () => {
    this.http.post('AC', 'SNM017P_ExportPrice_Delete', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.SearchExportPrice();
        }
      });
  }

  ConfirmSave() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
  }

  Save = () => {
    this.http.post('AC', 'SNM017P_ExportPrice_Save', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.SearchExportPrice();
          this.dialogMain.Close();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  CloseDialog() {
    this.InitData();
    this.dialogMain.Close();
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_NAME",
    PlaceholderText: "Select Customer Code",
    SourceController: "AC",
    SourceMethodName: "SNM017P_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: { DATA: this.params },
    UpperCase: true
  }

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part Code",
    SourceController: "AC",
    SourceMethodName: "SNM017P_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: { DATA: this.params },
    UpperCase: true
  }

  public lookupCurrencyCodeConfig: any = {
    ColName: "LOOKUP_CURRENCY",
    PlaceholderText: "Select Currency Code",
    SourceController: "AC",
    SourceMethodName: "GetCurrency",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.PART_NO = null;
  }

  public SetSelectedPartNo(value: any) {
    this.params.PART_NO = value.PART_NO;
  }

  public SetSelectedCurrencyCode(value: any) {
    this.params.CURRENCY_CODE = value.CURRENCY_CODE;
  }

  public dialogLookupCustomerCodeConfig: any = {
    ColName: "CODE_NAME",
    PlaceholderText: "Select Customer Code",
    SourceController: "wPMS",
    SourceMethodName: "GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public dialogLookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }



  public SetSelectedDialogCustomerCode(value: any) {
    this.Data.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.Data.CUSTOMER_NAME = value.CUST_NAME_TH;
  }

  public SetSelectedDialogPartNo(value: any) {
    this.Data.PART_NO = value.PART_NO;
    this.Data.PART_NAME = value.PART_NAME;
  }

  public SetSelectedDialogCurrencyCode(value: any) {
    this.Data.CURRENCY_CODE = value.CURRENCY_CODE;
    this.Data.CURRENCY_NAME = value.CURRENCY_NAME;
  }


  public dialogLookupEffectiveDateConfig: any = {
    ColName: "EFFECTIVE_DATE",
    PlaceholderText: "Select Effective Date",
    SourceController: "AC",
    SourceMethodName: "SNM017_GetEffectiveDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedDialogEffectiveDateStart(value: any) {
    this.params.EFFECTIVE_DATE_S = value.EFFECTIVE_DATE;
  }

  public SetSelectedDialogEffectiveDateEnd(value: any) {
    this.params.EFFECTIVE_DATE_E = value.EFFECTIVE_DATE;
  }


  public OpenReport() {
    this.dialogReport.OpenDialog();
  }

  public CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    if (this.params.EFFECTIVE_DATE_S && this.params.EFFECTIVE_DATE_E) {
      this.global.GoToReport("PMS_RPT_SALES_SNM017R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_EFFECTIVE_DATE_S: moment(this.params.EFFECTIVE_DATE_S).format('DD-MM-YYYY'),
        P_EFFECTIVE_DATE_E: moment(this.params.EFFECTIVE_DATE_E).format('DD-MM-YYYY'),

      })
    }
    else {
      this.modal.warning("Please fill Effective Date", this.viewRef);
    }
  }
}
