import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';

@Component({
  selector: 'snm100p',
  templateUrl: './SNM100P.component.html',
  styleUrls: ['./SNM100P.component.css']
})

export class SNM100PComponent implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }

  @ViewChild("dialogMain", { static: false }) dialogMain: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;
  @ViewChild("dialogReport", { static: false }) dialogReport: any;

  public params: any = {}
  public FactorList: any = [];
  public OrderClassList: any = [];
  public Data: any = {};
  public FrmTitle: any;
  public IsEdit: any = true;

  public lookupCustomerCodeConfig: any = {
    ColName: "CODE_NAME",
    PlaceholderText: "Select Customer Code",
    SourceController: "wPMS",
    SourceMethodName: "GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0
  }

  ngOnInit() {
    this.Search()
    this.getOrderClass()
  }

  Search() {
    this.http.post('IC', 'SNM100P_Getdata', this.params)
      .subscribe(res => {
        this.FactorList = res.Table;
      })
  }

  getOrderClass() {
    this.http.get('IC', 'SNM100P_GetOrderClass')
      .subscribe(res => {
        this.OrderClassList = res.Table;
      })
  }

  InitData() {
    this.Data = {};
  }

  OpenMainDialog() {
    this.FrmTitle = "New Export Factor";
    this.InitData();
    this.IsEdit = false;
    this.dialogMain.OpenDialog();
  }

  Edit(P_data) {
    this.FrmTitle = "Edit Export Factor";
    this.InitData();
    this.Data = P_data;
    this.IsEdit = true;
    this.dialogEdit.OpenDialog();
  }

  Delete(P_data) {
    this.Data = P_data;
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.ConfirmDeleteRow);
  }

  ConfirmDeleteRow = () => {
    this.http.post('IC', 'SNM100P_ETE_Factor_Delete', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.Search();
        }
      });
  }

  SaveAdd() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)
  }

  ConfirmSaveAdd = () => {
    this.http.post('IC', 'SNM100P_ETE_Factor_Save', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.params.CUSTOMER_CODE = this.Data.CUSTOMER_CODE
          this.params.CUSTOMER_NAME = this.Data.CUSTOMER_NAME
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  CancelMain() {
    this.InitData();
    this.dialogMain.Close();

  }

  CancelEdit() {
    this.InitData();
    this.dialogEdit.Close();
  }

  public SetSelectedCustomerCode(value: any) {
    this.Data.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.Data.CUSTOMER_NAME = value.CUST_NAME_TH;
  }
  public SetParamsCustomerCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUST_NAME_TH;
    this.Search()
  }


  public lookupMasterCodeConfig: any = {
    ColName: "MASTER_CODE",
    PlaceholderText: "Select Master Code",
    SourceController: "SL",
    SourceMethodName: "SNM100P_GetMasterCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0
  }

  public SetParamsMasterCodeStart(value: any) {
    this.params.MASTER_CODE_S = value.MASTER_CODE;
  }

  public SetParamsMasterCodeEnd(value: any) {
    this.params.MASTER_CODE_E = value.MASTER_CODE;
  }



  public OpenReport() {
    this.dialogReport.OpenDialog();
  }

  public CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    if (this.params.MASTER_CODE_S && this.params.MASTER_CODE_E) {
      this.global.GoToReport("PMS_RPT_SALES_SNM047R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_MASTER_CODE_S: this.params.MASTER_CODE_S,
        P_MASTER_CODE_E: this.params.MASTER_CODE_E,

      })
    }
    else {
      this.modal.warning("Please fill Master Code", this.viewref);
    }
  }
}


