import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'snse015d',
  templateUrl: './SNSE015_D.component.html',
  styleUrls: ['./SNSE015_D.component.css']
})



export class SNSE015_DComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {}
  public tableData: any;


  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE015_D_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_D_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE : null,
      BRANCH_CODE : null
    },
    UpperCase: true
  }

  
  ngOnInit() {
    this.params.CHK_PRINT_PICKING_CARD = 'Y'
  }


  public SetSelectedCustomerCode(values: any) {
    console.log('vvvv',values)
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.BRANCH_NAME = values.BRANCH_NAME;
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.lookupOrderNoConfig.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.lookupOrderNoConfig.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.BO_FLAG = values.BO_FLAG;
    this.params.DSP_BRANCH_STATUS = values.V_DSP_BRANCH_STATUS;
    this.params.DSP_BRANCH_STATUS_DESC = values.V_DSP_BRANCH_STATUS_DESC;
    this.params.DSP_CREDIT_LIMIT = values.V_DSP_CREDIT_LIMIT;
    this.params.DSP_CREDIT_AVAILABLE = values.V_DSP_CREDIT_AVAILABLE;
  }

  Search = () => {
    this.tableData = null;
    this.Http.post('SL', 'SNSE015_D_getData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        console.log(this.tableData)
        var V_ORDER_AMT = 0;
        var sum_INVOICE_AMT = 0;
        var V_ORDER_QTY = 0

        this.tableData.forEach((e) => {
          if (e.STATUS_CODE == 'N') {
            V_ORDER_QTY = e.ORDER_QTY;
          }
          else {
            V_ORDER_QTY = e.ACCEPT_QTY;
          }
          if (e.LOCK_SALES == 0 && e.OH_QTY > 0) {

            if (e.OH_QTY >= e.ORDER_QTY) {
              V_ORDER_AMT = e.ORDER_QTY * e.UNIT_PRICE_B
            }
            else {
              V_ORDER_AMT = e.OH_QTY * e.UNIT_PRICE_B;
            }
            sum_INVOICE_AMT += V_ORDER_AMT
          }
        });
        this.params.EST_INVOICE_AMT = sum_INVOICE_AMT;
      })
  }

  CheckboxChange(event) {
    if (event.checked) {
      this.params.CHK_PRINT_PICKING_CARD = 'Y'
    }
    else {
      this.params.CHK_PRINT_PICKING_CARD = 'N'
    }
  }

  rowClick(row) {
    this.params.PART_NAME = row.PART_NAME
  }




  ConfirmAllowcate() {
    this.modal.confirm('Do you want to allowcate this order?', this.viewref, this.allocateOrder)
  }

  allocateOrder = () => {
    this.Http.post('SL', 'SNSE015_D_Allocate', this.params)
      .subscribe(res => {
        console.log(res)
        if (res.Table[0].STATUS == 'DONE' && !res.Table[0].MSG) {
          this.modal.info("Allowcate Order Completed.", this.viewref);
          this.params.DSP_FROM_INVOICE = res.Table[0].DSP_FROM_INVOICE;
          this.params.DSP_TO_INVOICE = res.Table[0].DSP_TO_INVOICE;
          this.params.DSP_CREDIT_LIMIT = res.Table[0].DSP_CREDIT_LIMIT;
          this.params.DSP_CREDIT_AVAILABLE = res.Table[0].DSP_CREDIT_AVAILABLE;
          //this.params.ACT_INVOICE_AMT = res.Table[0].DSP_ACT_INVOICE_AMT;
          //this.params.EST_INVOICE_AMT = res.Table[0].DSP_EST_INVOICE_AMT;
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MSG, this.viewref);
        }
      })
  }
}
