import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from '../../../core/modal.service';
import { MatTableDataSource } from '@angular/material/table';
import { FormControl, Validators } from '@angular/forms';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'snm006p',
    templateUrl: './SNM006P.component.html',
    styleUrls: ['./SNM006P.component.css']
})



export class SNM006PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private route: ActivatedRoute,
        private global: Globals
    ) {
    }

    @ViewChild("dialog", { static: false }) dialog: any;
    @ViewChild("dialog2", { static: false }) dialog2: any;
    public data: any = [];
    public VENDOR_CODE: any = null;
    public VENDOR_NAME: any;
    public CategoryLits: any = [];
    public BranchList: any = [];
    public BranchListAdd: any = [];

    public Param = {
        CUSTOMER_CODE: null,
        BRANCH_CODE: null,
        VENDOR_CODE: null,
        VENDOR_NAME: null
    }

    CustomerControl = new FormControl('', [Validators.required]);

    BranchControl = new FormControl('', [Validators.required]);

    VendorControl = new FormControl('', [Validators.required]);


    public OilPoList = [{ ID: 'D', NAME: 'Daily' }, { ID: 'W', NAME: 'Weekly' }, { ID: 'M', NAME: 'Monthly' }]

    public ConfigCustomer: any = {
        ColName: "CODE_NAME",
        ColValue: "CUSTOMER_CODE",
        PlaceholderText: "Select Customer",
        SourceController: "wPMS",
        SourceMethodName: "GetCustomerCode",
        NoOfShowRecords: 25,
        MinLengthSearch: 3,
        UpperCase: true
    }

    public ConfigBranch: any = {
        ColName: "BRANCH_NAME",
        ColValue: "BRANCH_CODE",
        PlaceholderText: "Branch Code",
        MinLengthSearch: 0,

    }

    public ConfigVendor: any = {
        ColName: "LOOKUP_VENDOR_NAME",
        ColValue: "",
        PlaceholderText: "Select Vendor",
        SourceController: "wPMS",
        SourceMethodName: "GetVendorCode",
        NoOfShowRecords: 20,
        MinLengthSearch: 1,
        UpperCase: true
    }

    public AddData: any = {
        CUSTOMER_CODE: null,
        BRANCH_CODE: null,
        VENDOR_CODE: null,
        OIL_CUST_CODE: null,
        OIL_SHIP_CODE: null,
        SERVICE_BRANCH: null,
        OIL_PO_CYCLE: null
    }

    public EditData: any = {
        CUSTOMER_CODE: null,
        BRANCH_CODE: null,
        VENDOR_CODE: null,
        OIL_CUST_CODE: null,
        OIL_SHIP_CODE: null,
        SERVICE_BRANCH: null,
        OIL_PO_CYCLE: null
    }
    public valid: boolean = false;
    public TableData: any = [];
    public hideCols: Array<string> = []

    ngOnInit() {
        // this.GetBranch();

        this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    }


    GetBranch(customerCode, type) {
        this.http.get('IC', 'SNM006P_GetBranch', customerCode)
            .subscribe(res => {
                type === "Search" ? this.BranchList = res.Table : this.BranchListAdd = res.Table;
                // branchList = res.Table
            })
    }

    ValidateSave(CUSTOMER_CODE, BRANCH_CODE, VENDOR_CODE) {

        this.http.get('IC', 'SNM006P_ValidateSave', CUSTOMER_CODE, BRANCH_CODE, VENDOR_CODE)
            .subscribe(res => {

            })
    }

    ValidateCustomer() {

        if (this.AddData.CUSTOMER_CODE) {

            this.http.get('IC', 'SNM006P_ValidateCustomerCode', this.AddData.CUSTOMER_CODE)
                .subscribe(res => {
                    if (res.Table[0].COUNTROW == 0) {
                        this.modal.warning("Invalid value for field CUSTOMER_CODE", this.viewref)
                        this.valid = false;
                    } else {
                        this.valid = true;
                    }
                })
        }
    }

    clearSearch() {
        this.Param = {
            CUSTOMER_CODE: null,
            BRANCH_CODE: null,
            VENDOR_CODE: null,
            VENDOR_NAME: null
        };
    }

    openDialog() {
        this.AddData = {};
        this.CustomerControl.reset();
        this.BranchControl.reset();
        this.VendorControl.reset();

        this.valid = false;
        this.dialog.OpenDialog()
    }

    SelectedCus(event, type) {
        if (type == 'Search') {
            this.Param.CUSTOMER_CODE = event;
            this.GetBranch(event, type);
        } else if (type == 'Add') {
            this.AddData.CUSTOMER_CODE = event;
            this.GetBranch(event, type);
            if (event) {
                this.valid = true
            }
        } else {
            this.EditData.CUSTOMER_CODE = event;
        }

    }

    SelectedBranch(event, type) {

        if (type == 'Search') {
            this.Param.BRANCH_CODE = event;
        } else if (type == 'Add') {
            this.AddData.BRANCH_CODE = event
        } else {
            this.EditData.BRANCH_CODE = event
        }
    }

    SelectedVendor(event, type) {
        if (type == 'Search') {
            this.Param.VENDOR_CODE = event.VENDOR_CODE
            this.Param.VENDOR_NAME = event.LOOKUP_VENDOR_NAME
        } else if (type == 'Add') {
            this.AddData.VENDOR_CODE = event.VENDOR_CODE
            this.AddData.VENDOR_NAME = event.LOOKUP_VENDOR_NAME
        } else {
            this.EditData.VENDOR_CODE = event.VENDOR_CODE
            this.EditData.VENDOR_NAME = event.LOOKUP_VENDOR_NAME
        }
    }


    Search() {
        if (!this.Param.CUSTOMER_CODE && !this.Param.BRANCH_CODE && !this.Param.VENDOR_CODE) {
            this.modal.warning('Please input at least 1 criteria!', this.viewref)
        } else {
            this.data = [];
            this.http.post('IC', 'SNM006P_GetData', this.Param)
                .subscribe(res => {
                    this.data = res.Table;
                })
        }
    }


    SaveAdd() {

        this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)

    }

    ConfirmSaveAdd = () => {

        this.http.post('IC', 'SNM006P_InsertCustomerOil', this.AddData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    (!this.Param.CUSTOMER_CODE && !this.Param.BRANCH_CODE && !this.Param.VENDOR_CODE) ? null : this.Search();
                    this.dialog.Close();
                    this.ClearData();

                } else if (res.Table[0].STATUS == 'Duplicate') {
                    this.modal.warning('No change to save. Found duplicate record.', this.viewref);
                }
                else {
                    this.modal.error('No change to save. Something went wrong.', this.viewref);
                }
            })
    }

    CancelAdd() {

        this.dialog.Close();
        //this.ClearData();

    }

    EditCategory(data) {

        this.EditData.CUSTOMER_CODE = data.CUSTOMER_CODE
        this.EditData.BRANCH_CODE = data.BRANCH_CODE
        this.EditData.VENDOR_CODE = data.VENDOR_CODE
        this.EditData.VENDOR_NAME = data.VENDOR_NAME
        this.EditData.OIL_CUST_CODE = data.OIL_CUST_CODE
        this.EditData.OIL_SHIP_CODE = data.OIL_SHIP_CODE
        this.EditData.SERVICE_BRANCH = data.SERVICE_BRANCH
        this.EditData.OIL_PO_CYCLE = data.OIL_PO_CYCLE
        this.EditData.LAST_UPD_BY = data.LAST_UPD_BY
        this.EditData.LAST_UPD_DATE = data.LAST_UPD_DATE

        this.dialog2.OpenDialog();
    }

    SaveEdit() {

        this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveEdit)

    }

    ConfirmSaveEdit = () => {

        this.http.post('IC', 'SNM006P_EditCustomerOil', this.EditData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.Search();
                    this.dialog2.Close();

                } else {
                    this.modal.warning('No change to save. Something went wrong.', this.viewref);
                }
            })
    }

    Delete(data) {

        this.modal.confirm('Do you want to delete record?', this.viewref, () => this.ConfirmDelete(data))
    }

    ConfirmDelete = data => {

        //this.data.splice(this.index, 1)
        //this.data = this.data.slice();
        this.http.post('IC', 'SNM006P_DeleteCustomerOil', data)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.Search();
                } else {
                    this.modal.warning('No change to save. Something went wrong.', this.viewref);
                }
            })
    }

    CancelEdit() {
        this.dialog2.Close();
    }

    ClearData() {
        this.AddData.CUSTOMER_CODE = null;
        this.AddData.BRANCH_CODE = null;
        this.AddData.VENDOR_CODE = null;
        this.AddData.OIL_CUST_CODE = null;
        this.AddData.OIL_SHIP_CODE = null;
        this.AddData.SERVICE_BRANCH = null;
        this.AddData.OIL_PO_CYCLE = null;

    }

}

