import { Component, OnInit, ViewContainerRef, ViewChild, Input, ɵNOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { FormControl, Validators, FormGroup } from '@angular/forms';
import { dateFormatPipe } from 'src/app/core/app.pipe';
import { validateVerticalPosition } from '@angular/cdk/overlay';
import { Globals } from 'src/app/core/global';

enum ACTION_TYPE {
    Add = "Add New Factor",
    Edit = "Edit Factor",
    Delete = "Delete Factor"
}

@Component({
    selector: 'SNM040P',
    templateUrl: './SNM040P.component.html',
    styleUrls: ['./SNM040P.component.css']
})
export class SNM040PComponent implements OnInit {
    constructor(
        protected http: HttpService,
        protected router: Router,
        public modal: ModalService,
        public viewref: ViewContainerRef,
        private route: ActivatedRoute,
        private global: Globals
    ) {
    }



    public VendorLookupConfig: any = {
        ColName: "LOOKUP_VENDOR_NAME",
        PlaceholderText: "Select Vendor",
        SourceController: "wPMS",
        SourceMethodName: "GetVendorCode",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    public SearchVendor = "";
    public SearchVendorCode = "";
    public ETAList: Array<any> = [];
    public Action: ACTION_TYPE;
    public JobTypeList: Array<any> = [];
    public VendorTypeList: Array<any> = [];
    public JobMethodList: Array<any> = [];
    public CalculateTypeList: Array<any> = [
        { CALCULATE_TYPE: "C", DESCRIPTION: "C : Normal Calendar" },
        { CALCULATE_TYPE: "W", DESCRIPTION: "W : Working Calendar" }]
    public FactorMaintainForm: FormGroup;
    public disVendorAutoComp: boolean;
    public RecordControl: any = {
        LastUpdateBy: "",
        LastUpdateDate: "",
        CreateBy: "",
        CreateDate: ""
    }

    public sumETP: number = 0;

    public hideCols: Array<string> = [];

    @ViewChild('dialog', { static: false }) dialog: any;

    ngOnInit(): void {
        this.global.GetRoleDetail().CHG === "N" && this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push('ACTION') : null;

        this.Action = ACTION_TYPE.Add;
        this.InitialListControl();
        this.FactorMaintainForm = new FormGroup({
            VendorCodeCtrl: new FormControl('', [Validators.required]),
            VendorTypeCtrl: new FormControl(''),
            JobTypeCtrl: new FormControl('', [Validators.required]),
            JobMethodCtrl: new FormControl('', [Validators.required]),
            LeadTimeETDCtrl: new FormControl(null, [Validators.required, Validators.min(1)]),
            LeadTimeETPCtrl: new FormControl(null, [Validators.required, Validators.min(1)]),
            LeadTimeETAEOBkkCtrl: new FormControl(null, [Validators.required, Validators.min(1)]),
            LeadTimeETAEOUpcCtrl: new FormControl(null, [Validators.required, Validators.min(1)]),
            LeadTimeETAROBkkCtrl: new FormControl(null, [Validators.required, Validators.min(1)]),
            LeadTimeETAROUpcCtrl: new FormControl(null, [Validators.required, Validators.min(1)]),
            CalculateTypeCtrl: new FormControl('', [Validators.required]),
            VendorDescCtrl: new FormControl(''),
        });
        this.FactorMaintainForm.controls['VendorTypeCtrl'].disable();
        this.FactorMaintainForm.controls['LeadTimeETDCtrl'].valueChanges.subscribe((value: number) => {
            this.FactorMaintainForm.controls['LeadTimeETPCtrl'].setValue(<number>value + this.sumETP)
        })

    }

    SetSearchVendor(event) {
        this.SearchVendor = event.LOOKUP_VENDOR_NAME;
        this.SearchVendorCode = event.VENDOR_CODE;
        this.GetETAFactorList();
    }

    ValidateSearchVendor(autoComplete) {
        autoComplete.query()

        if (!this.SearchVendor) {
            this.SearchVendorCode = "";
            this.GetETAFactorList();
        }
    }

    LoadJobMethodList(jobType, jobMethod?: string) {

        this.FactorMaintainForm.get("JobMethodCtrl").setValue("");
        this.JobMethodList = [];
        this.http.get("IC", "SNM040P_GetJobMethod", jobType)
            .subscribe(result => {
                this.JobMethodList = result.Table;


                this.FactorMaintainForm.get("JobMethodCtrl").setValue(!jobMethod ? "" : jobMethod);
            })

    }

    GetETAFactorList() {
        this.ETAList = [];
        this.http.get("IC", "SNM040P_GetETAData", !this.SearchVendorCode ? "" : this.SearchVendorCode)
            .subscribe(result => {
                this.ETAList = result.Table;
                console.log(this.ETAList)
            })
    }

    InitialListControl() {
        this.LoadJobTypeList();
        this.LoadVendorTypeList();
    }


    LoadJobTypeList() {

        this.JobTypeList = [];
        this.http.get("wPMS", "GetJobTypeMaster")
            .subscribe(result => {
                this.JobTypeList = result.Table;
            })

    }

    LoadVendorTypeList() {

        this.VendorTypeList = [];
        this.http.get("wPMS", "GetVendorTypeList")
            .subscribe(result => {
                this.VendorTypeList = result.Table;
            })

    }

    AddNewFactor() {
        this.Action = ACTION_TYPE.Add;
        this.dialog.title = ACTION_TYPE.Add;
        this.disVendorAutoComp = false;
        this.FactorMaintainForm.reset();
        this.FactorMaintainForm.controls['VendorDescCtrl'].enable();
        this.FactorMaintainForm.controls['JobTypeCtrl'].enable();
        this.FactorMaintainForm.controls['JobMethodCtrl'].enable();
        this.RecordControl = {};
        this.sumETP = 1

        this.dialog.OpenDialog();
    }

    EditFactor(row) {
        this.Action = ACTION_TYPE.Edit;
        this.dialog.title = ACTION_TYPE.Edit;
        this.disVendorAutoComp = true;
        this.LoadETAFactorInfo(row);
        this.sumETP = 0

        this.dialog.OpenDialog();
    }

    DeleteFactor(row) {

        this.modal.confirm('Do you want to delete this factor?', this.viewref, () => {
            this.Action = ACTION_TYPE.Delete;
            this.SaveChangeDelete(
                !row.JOB_TYPE ? "" : row.JOB_TYPE,
                !row.JOB_METHOD ? "" : row.JOB_METHOD,
                !row.VENDOR_TYPE ? "" : row.VENDOR_TYPE,
                !row.VENDOR_CODE ? "" : row.VENDOR_CODE);
        });
    }

    LoadETAFactorInfo(row) {
        let ETAFactor: any;

        this.FactorMaintainForm.reset();
        this.http.get("IC", "SNM040P_GetETAInfo",
            !row.JOB_TYPE ? "" : row.JOB_TYPE,
            !row.JOB_METHOD ? "" : row.JOB_METHOD,
            !row.VENDOR_TYPE ? "" : row.VENDOR_TYPE,
            !row.VENDOR_CODE ? "" : row.VENDOR_CODE)
            .subscribe(result => {

                if (result.Table.length == 1) {
                    ETAFactor = result.Table[0];
                    this.SetETAFactorInfoToCtrl(ETAFactor);
                }
            })
    }

    SetETAFactorInfoToCtrl(factor) {
        console.log(factor)
        this.FactorMaintainForm.controls["VendorCodeCtrl"].setValue(!factor.VENDOR_CODE ? "" : factor.VENDOR_CODE);
        this.FactorMaintainForm.controls["VendorDescCtrl"].setValue(!factor.VENDOR_DESC ? "" : factor.VENDOR_DESC);

        this.FactorMaintainForm.controls["VendorTypeCtrl"].setValue(!factor.VENDOR_TYPE ? "" : factor.VENDOR_TYPE);
        this.FactorMaintainForm.controls["JobTypeCtrl"].setValue(!factor.JOB_TYPE ? "" : factor.JOB_TYPE);
        this.LoadJobMethodList(!factor.JOB_TYPE ? "" : factor.JOB_TYPE
            , !factor.JOB_METHOD ? "" : factor.JOB_METHOD);

        this.FactorMaintainForm.controls["LeadTimeETDCtrl"].setValue(!factor.LEAD_TIME_ETD ? "" : factor.LEAD_TIME_ETD);
        this.FactorMaintainForm.controls["LeadTimeETPCtrl"].setValue(!factor.LEAD_TIME_ETP ? "" : factor.LEAD_TIME_ETP);
        this.FactorMaintainForm.controls["LeadTimeETAEOBkkCtrl"].setValue(!factor.ETA_EO_BKK ? "" : factor.ETA_EO_BKK);
        this.FactorMaintainForm.controls["LeadTimeETAEOUpcCtrl"].setValue(!factor.ETA_EO_UPC ? "" : factor.ETA_EO_UPC);
        this.FactorMaintainForm.controls["LeadTimeETAROBkkCtrl"].setValue(!factor.ETA_EO_BKK ? "" : factor.ETA_RO_BKK);
        this.FactorMaintainForm.controls["LeadTimeETAROUpcCtrl"].setValue(!factor.ETA_EO_UPC ? "" : factor.ETA_RO_UPC);
        this.FactorMaintainForm.controls["CalculateTypeCtrl"].setValue(!factor.CALCULATE_TYPE ? "" : factor.CALCULATE_TYPE);

        this.FactorMaintainForm.controls['VendorDescCtrl'].disable();
        this.FactorMaintainForm.controls['JobTypeCtrl'].disable();
        this.FactorMaintainForm.controls['JobMethodCtrl'].disable();

        this.RecordControl.LastUpdateBy = !factor.LAST_UPD_BY ? "" : factor.LAST_UPD_BY;
        this.RecordControl.LastUpdateDate = !factor.LAST_UPD_DATE ? "" : factor.LAST_UPD_DATE;
        this.RecordControl.CreateBy = !factor.CREATE_BY ? "" : factor.CREATE_BY;
        this.RecordControl.CreateDate = !factor.CREATE_DATE ? "" : factor.CREATE_DATE
    }

    SetVendorCodeLookup(event) {
        this.FactorMaintainForm.controls["VendorDescCtrl"].setValue(event.LOOKUP_VENDOR_NAME);
        this.FactorMaintainForm.controls["VendorCodeCtrl"].setValue(event.VENDOR_CODE);

        this.GetVendorType();

    }

    GetVendorType() {
        let vendorCode = this.FactorMaintainForm.get("VendorCodeCtrl").value;
        let VendorType = "";

        if (vendorCode) {
            this.http.get("wPMS", "GetVendorTypeByVendorCode", vendorCode)
                .subscribe(result => {
                    VendorType = result;
                    this.FactorMaintainForm.get("VendorTypeCtrl").setValue(VendorType);

                })
        }
    }

    SaveChange = () => {
        console.log("Mode => ", this.Action)


        if (this.Action == ACTION_TYPE.Add) {
            this.SaveChangeAdd();
            //console.log(JSON.stringify(this.FactorMaintainForm.getRawValue()));
        }

        if (this.Action == ACTION_TYPE.Edit) {
            this.SaveChangeEdit();
        }

    }

    SaveChangeAdd() {

        this.http.post('IC', 'SNM040P_SaveChangeAdd', JSON.stringify(this.FactorMaintainForm.getRawValue()))
            .subscribe(res => {
                console.log(res);

                if (res === "Done") {
                    this.modal.info('Add completed.', this.viewref, this.dialog.Close())
                    this.GetETAFactorList();
                } else {
                    this.modal.error('Add failed, due to ' + res, this.viewref)
                }

            });
    }

    SaveChangeEdit() {

        this.http.post('IC', 'SNM040P_SaveChangeEdit', JSON.stringify(this.FactorMaintainForm.getRawValue()))
            .subscribe(res => {
                console.log(res);

                if (res === "Done") {
                    this.modal.info('Edit completed.', this.viewref, this.dialog.Close());
                    this.GetETAFactorList();
                } else {
                    this.modal.error('Edit failed, due to ' + res, this.viewref)
                }

            });
    }

    SaveChangeDelete(
        pJobType,
        pJobMethod,
        pVendorType,
        pVendorCode
    ) {
        this.http.get('IC', 'SNM040P_SaveChangeDelete', pJobType, pJobMethod, pVendorType, pVendorCode)
            .subscribe(res => {
                console.log(res);

                if (res === "Done") {
                    this.modal.info('Delete completed.', this.viewref);
                    this.GetETAFactorList();
                } else {
                    this.modal.error('Delete failed, due to ' + res, this.viewref)
                }

            });
    }

    //Validator error message
    GetVendorCodeErrorMessage() {
        return this.FactorMaintainForm.controls["VendorCodeCtrl"].hasError('required') ? 'You must enter a value' : '';
    }

    GetJobTypeErrorMessage() {
        return this.FactorMaintainForm.controls["JobTypeCtrl"].hasError('required') ? 'You must enter a value' : '';
    }

    GetJobMethodErrorMessage() {
        return this.FactorMaintainForm.controls["JobMethodCtrl"].hasError('required') ?
            'You must enter a value' : '';
    }

    GetLeadTimeETDErrorMessage() {
        let msg = ''
        if (this.FactorMaintainForm.controls["LeadTimeETDCtrl"].hasError('required')) {
            msg = 'You must enter a value'
        } else if (this.FactorMaintainForm.controls["LeadTimeETDCtrl"].hasError('min')) {
            msg = 'Value must more than 0'
        }
        return msg;
    }

    GetLeadTimeETPErrorMessage() {
        let msg = ''
        if (this.FactorMaintainForm.controls["LeadTimeETPCtrl"].hasError('required')) {
            msg = 'You must enter a value'
        } else if (this.FactorMaintainForm.controls["LeadTimeETPCtrl"].hasError('min')) {
            msg = 'Value must more than 0'
        }
        return msg;
    }

    GetLeadTimeETAEOBkkErrorMessage() {
        let msg = ''
        if (this.FactorMaintainForm.controls["LeadTimeETAEOBkkCtrl"].hasError('required')) {
            msg = 'You must enter a value'
        } else if (this.FactorMaintainForm.controls["LeadTimeETAEOBkkCtrl"].hasError('min')) {
            msg = 'Value must more than 0'
        }
        return msg;
    }

    GetLeadTimeETAEOUpcErrorMessage() {
        let msg = ''
        if (this.FactorMaintainForm.controls["LeadTimeETAEOUpcCtrl"].hasError('required')) {
            msg = 'You must enter a value'
        } else if (this.FactorMaintainForm.controls["LeadTimeETAEOUpcCtrl"].hasError('min')) {
            msg = 'Value must more than 0'
        }
        return msg;
    }

    GetLeadTimeETAROBkkErrorMessage() {
        let msg = ''
        if (this.FactorMaintainForm.controls["LeadTimeETAROBkkCtrl"].hasError('required')) {
            msg = 'You must enter a value'
        } else if (this.FactorMaintainForm.controls["LeadTimeETAROBkkCtrl"].hasError('min')) {
            msg = 'Value must more than 0'
        }
        return msg;
    }

    GetLeadTimeETAROUpcErrorMessage() {
        let msg = ''
        if (this.FactorMaintainForm.controls["LeadTimeETAROUpcCtrl"].hasError('required')) {
            msg = 'You must enter a value'
        } else if (this.FactorMaintainForm.controls["LeadTimeETAROUpcCtrl"].hasError('min')) {
            msg = 'Value must more than 0'
        }
        return msg;
    }

    GetCalculateTypeErrorMessage() {
        return this.FactorMaintainForm.controls["CalculateTypeCtrl"].hasError('required') ? 'You must enter a value' : '';
    }

    NumericKeyDown(event) {
        //console.log('Keydonw',event);
        let reg = /^[0-9]$/;

        if (event.keyCode == 8 || event.keyCode == 9 || event.keyCode == 46
            || event.keyCode == 37 || event.keyCode == 39) {
            return true;
        }

        return reg.test(event.key);
    }

    log(v) {
        console.log(v);

    }

}
