import { Component, OnInit, ViewContainerRef, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { MatTableDataSource } from '@angular/material/table';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';
import { MatPaginator } from '@angular/material/paginator';
import { Globals } from 'src/app/core/global';


@Component({
  selector: 'snm112p',
  templateUrl: './SNM112P.component.html',
  styleUrls: ['./SNM112P.component.css']
})

export class SNM112PComponent implements OnInit {


  constructor(
    private HttpService: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals

  ) {

  }
  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;

  public data: any;
  public SelectList: any;
  public Data: any;
  public headerList: Array<any> = [];
  public dataList: any = [];
  public displayedColumns: string[] = [];
  public Criterai = { PART_NO: '', VENDOR_CODE: null, ONLY_EXIST: 'N' }//PART_NO: '10324',VENDOR_CODE: '430'
  public Setselection = new SelectionModel<any>(true, []);
  public Delselection = new SelectionModel<any>(true, []);
  public CheckRecord: boolean = true;
  public qCheckSet: boolean = true;
  public qCheckDel: boolean = true;
  public Update: any = [];



  public dataForsave: any;

  public ConfigVendor: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public ConfigPart: any = {
    ColName: "LOOKUP_PART_NAME",
    ColValue: "PART_NO",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 30,
    MinLengthSearch: 5,
    UpperCase: true
  }

  ngOnInit() {
    this.getTableHeader();
    this.SelectList = [{ ID: 1, SELECT_CODE: "A001" }, { ID: 2, SELECT_CODE: "B002" }, { ID: 3, SELECT_CODE: "C003" }]
  }

  getTableHeader() {
    this.HttpService.get("System", "GetHeaderGridView", 'SNM112PList')
      .subscribe(result => {
        this.headerList = result.filter(v => v.VISIBILITY === true);
        this.displayedColumns = this.headerList.map(v => v.FIELD_NAME);

      })
  }

  Search() {

    this.Criterai.ONLY_EXIST = this.CheckRecord == true ? 'Y' : 'N'

    if (!this.Criterai.VENDOR_CODE && !this.Criterai.PART_NO && this.Criterai.ONLY_EXIST == 'N') {

      this.modal.warning('Please input at least 1 criteria!', this.viewref)

      // } else if (!this.Criterai.VENDOR_CODE && this.Criterai.PART_NO.length <= 5 && this.Criterai.ONLY_EXIST == 'N') {

      //     this.modal.warning('Please input [Part No] atleast 5 digit!', this.viewref)

    } else {
      this.GetData();
    }

  }

  GetData() {
    this.Data = [];
    this.HttpService.post("IC", "SNM112P_SEARCH_RESULT", JSON.stringify(this.Criterai))
      .subscribe(result => {
        if (result.Table.length > 0) {
          this.Data = result.Table
          this.Update = Math.max.apply(Math, this.Data.map(x => x.LAST_UPD_DATE))
          this.qCheckSet = this.Data.some(x => x.DSP_SET_FLAG == 'N')
          this.qCheckDel = this.Data.some(x => x.DSP_SET_FLAG == 'Y')
          this.Update = this.Data.reduce((prev, current) => (prev.LAST_UPD_DATE > current.LAST_UPD_DATE) ? prev : current)
        }

      })
  }

  isSetAllSelected() {
    const numSelected = this.Setselection.selected.length;
    const numRows = this.Data.filter(x => x.DSP_SET_FLAG == 'N').length;
    return numSelected === numRows;
  }

  SetToggle() {
    this.isSetAllSelected() ?
      this.Setselection.clear() :
      this.Data.forEach(row => {
        if (row.DSP_SET_FLAG == 'N') {
          this.Setselection.select(row)
        }
      });
  }

  isDelAllSelected() {
    const numSelected = this.Delselection.selected.length;
    const numRows = this.Data.filter(x => x.DSP_SET_FLAG == 'Y').length;
    return numSelected === numRows;
  }

  DelToggle() {

    this.isDelAllSelected() ?
      this.Delselection.clear() :
      this.Data.forEach(row => {
        if (row.DSP_SET_FLAG == 'Y') {
          this.Delselection.select(row)
        }
      });
    //this.dataList.data.forEach(row => this.Delselection.select(row));
  }

  Save() {
    if (this.Setselection.selected.length == 0 && this.Delselection.selected.length == 0) {
      this.modal.warning('Please Select Data!', this.viewref)

    } else {
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSave);
    }
  }

  ConfirmSave = () => {

    let Done: string;

    if (this.Setselection.selected.length !== 0 && this.Delselection.selected.length == 0) {

      let SetData: any[] = this.Setselection.selected
      if (SetData.length > 0) {
        this.HttpService.post('IC', 'SNM112P_SavePart', JSON.stringify(SetData))
          .subscribe(res => {
            if (res === "Done") {
              this.modal.info('Success', this.viewref)
              this.Setselection.clear()
              this.GetData();
            } else {

              this.modal.error('Failed', this.viewref)
            }

          }, (err) => {

            console.log(err, 'err')
          })
      }

    } else if (this.Setselection.selected.length == 0 && this.Delselection.selected.length !== 0) {

      let DelData: any[] = this.Delselection.selected
      this.HttpService.post('IC', 'SNM112P_DeletePart', JSON.stringify(DelData))
        .subscribe(res => {
          if (res === "Done") {
            this.modal.info('Success', this.viewref)
            this.Delselection.clear()
            this.GetData();
          } else {
            this.modal.error('Failed', this.viewref)
          }

        })
    } else {

      let SetData: any[] = this.Setselection.selected
      let DelData: any[] = this.Delselection.selected

      this.HttpService.post('IC', 'SNM112P_SavePart', JSON.stringify(SetData))
        .subscribe(res => {
          if (res === "Done") {

            this.HttpService.post('IC', 'SNM112P_DeletePart', JSON.stringify(DelData))
              .subscribe(res => {
                if (res === "Done") {
                  this.modal.error('Success', this.viewref)
                  this.Setselection.clear()
                  this.Delselection.clear()
                  this.GetData();
                }
              })
          } else {
            this.modal.error('Failed', this.viewref)

          }
        })

    }
  }


  SelectedVendor(event, type) {
    if (type == 'Search') {
      this.Criterai.VENDOR_CODE = event.VENDOR_CODE
    }
  }


}
