import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import * as moment from 'moment';


@Component({
  selector: 'snpp027',
  templateUrl: './snpp027.component.html',
  styleUrls: ['./snpp027.component.css']
})
export class SNPP027Component implements OnInit {

  constructor(
    private httpService: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {
  }

  private result: any;
  public poInfo = { Status: "", Message: "", FirstPoNo: "", LastPoNo: "" };

  ngOnInit() { }

  GeneratePO = () => {
    this.httpService.get("IC", "SNPP027_GeneratePO")
      .subscribe(result => {
        //console.log(result);

        if (result.Table.length > 0) {
          this.poInfo.Status = result.Table[0].STATUS;
          this.poInfo.Message = !result.Table[0].MESSAGE ? "" : result.Table[0].MESSAGE;
          this.poInfo.FirstPoNo = result.Table[0].FIRST_PO_NO;
          this.poInfo.LastPoNo = result.Table[0].LAST_PO_NO;

          //console.log("Result => ", this.poInfo);
          if (this.poInfo.Message == "") {
            this.modal.info('Process completed.', this.viewref);

          } else {
            this.modal.error(this.poInfo.Message, this.viewref);
          }

        }
        else {
          this.poInfo.Status = "Fail";
          this.poInfo.Message = "";
          this.poInfo.FirstPoNo = "";
          this.poInfo.LastPoNo = "";
          this.modal.error("Process failed.", this.viewref);
        }
      })
  }



  ExportReport() {
    if (this.poInfo.FirstPoNo && this.poInfo.LastPoNo) {
      let poDate: moment.Moment = moment();

      this.global.GoToReport("PMS_RPT_IC_PO_TO_SUPPLIER_V1",
        {
          P_PO_DATE: this.global.ConvertDateToFormatSTD(poDate),
          P_PO_NO_FROM: this.poInfo.FirstPoNo,
          P_PO_NO_TO: this.poInfo.LastPoNo,
        }
      );
    } else {
      this.modal.error("Please Generate PO first.", this.viewref);
    }
  }
}
