import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snsd172_f',
  templateUrl: './snsd172_f.component.html',
  styleUrls: ['./snsd172_f.component.css']
})



export class SNSD172_FComponent implements OnInit {
  //wait SP for qury data file then asign column fo dataset result
  displayedColumns: string[] = [
    'COMPANY_CODE' , 
    'GROUP_PART_NO' 
  ];

  //For dev show data set
  // public DataResult: PeriodicElement[];//shema of dataset result
  // public DataResult2: PeriodicElement[];
  //end For dev show data set

  //private Vendor_Type_List: any = [];//for combobox show data

  public showProgressBar: boolean;

  constructor(
    private HttpService: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) { 

  }

  public lookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    ColValue: "",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 35,
    MinLengthSearch : 2,
    UpperCase: true
  }

  public lookupConfigVendorStaff: any = {
    ColName: "STAFF_NAME_EN",
    ColValue: "STAFF_ID",
    PlaceholderText: "Select Staff Incharge",
    SourceController: "wPMS",
    SourceMethodName: "GetStaffInchargeG6",
    NoOfShowRecords: 50,
    MinLengthSearch : 0,
    UpperCase: true
  }

  public ListDataReportCondition: any = {
    MONTH: null,
    YEAR: Number,
    STAFF_ID : null,
    STAFF_NAME_EN : null,
    STAFF_NAME_TH : null,
    VENDOR_CODE_From : null,  
  };

  public vendor : any;

  ngOnInit() {
    //this.Vendor_Type_List = [{ ID: '', TEXT: "" },{ ID: 'J', TEXT: "J:Japan" }, { ID: 'K', TEXT: "K:Import(Not Japan)" }, { ID: 'L', TEXT: "L:Local" }]

    //this.ListDataReportCondition.MONTH = new Date().getMonth();
    //this.ListDataReportCondition.YEAR = new Date().getFullYear();

    this.HttpService.post('IC', 'SNSD172_F_GetMonthYearOfDateControl', this.ListDataReportCondition)
      .subscribe(res => {
        //console.log("show res:", res);
        if (res.Table.length > 0) {
          this.ListDataReportCondition.MONTH = res.Table[0].CURRENT_MONTH ;
          this.ListDataReportCondition.YEAR = res.Table[0].CURRENT_YEAR;
        } else {
          this.ListDataReportCondition.MONTH = new Date().getMonth();
          this.ListDataReportCondition.YEAR = new Date().getFullYear();
        }

      })
  }

  SetVendorCodeLookup(value) {
    this.vendor = value.LOOKUP_VENDOR_NAME;
    this.ListDataReportCondition.VENDOR_CODE_From = value.VENDOR_CODE;    
}

  exportToExcel() {
    if(!this.CheckSearchCondition()){
      return;
    } 
    console.log(this.ListDataReportCondition);
    this.showProgressBar = true;//show progress bar    
    this.HttpService.post('IC', 'SNSD172_GetDataSetToExcel', this.ListDataReportCondition)
        .subscribe(res => {
            console.log("Dataset",res);
            if(res.Table.length>0){
              this.downloadFile(this.convertDatatableToCSV(res),"SNSD172_F");
              this.showProgressBar = false;//hide progress bar    
            }else{
              //not data.
              this.showProgressBar = false;//hide progress bar    
              this.modal.info("Data not found!",this.viewref,null);
            }

        })
  }

  exportToExcelStaff(){
    if(!this.CheckSearchCondition()){
      return;
    } 
    //console.log(this.ListDataReportCondition); 
    this.showProgressBar = true;//show progress bar    
    this.HttpService.post('IC', 'SNSD172_GetDataSetToExcel_ForSup', this.ListDataReportCondition)
      .subscribe(res => {
            // console.log("res",res);
            //console.log("A",res.Table[0]["A"]);
            if(res.Table.length>0){
              this.downloadFile(this.convertDatatableToCSV(res),"SNSD172_F_Supplier");
              this.showProgressBar = false;//hide progress bar    
            }else{
              //not data.
              this.showProgressBar = false;//hide progress bar    
              this.modal.info("Data not found!",this.viewref,null);
            }
      });

  }

  convertDatatableToCSV(data){
    let str = '';
    for (let i = 0; i < data.Table.length; i++) {
      //fix colunm from SQL Select A,B,C,D,E,F,G,H,I,J,K,L
      if(data.Table[i]["A"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["A"] + ',';      }
      if(data.Table[i]["B"] == null){
        str += " " + ',';  
      }else{ 
        str += data.Table[i]["B"] + ',';      }
      if(data.Table[i]["C"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["C"] + ',';      }
      if(data.Table[i]["D"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["D"] + ',';      }
      if(data.Table[i]["E"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["E"] + ',';      }
      if(data.Table[i]["F"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["F"] + ',';      }
      if(data.Table[i]["G"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["G"] + ',';      }
      if(data.Table[i]["H"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["H"] + ',';      }
      if(data.Table[i]["I"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["I"] + ',';      }
      if(data.Table[i]["J"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["J"] + ',';      }
      if(data.Table[i]["K"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["K"] + ',';      }
      if(data.Table[i]["L"] == null){
        str += " " + ',';  
      }else{
        str += data.Table[i]["L"] + ',';      }
      str += '\r\n';
    }
    return str;
  }

  //writeContents(){}
  downloadFile(strfile:string, filename='data') {
    //let csvData = this.ConvertToCSV(data, ['name','age', 'average', 'approved', 'description']);
    let csvData = strfile;
    console.log(csvData)
    let blob = new Blob(['\ufeff' + csvData], { type: 'text/csv;charset=utf-8;' });
    let dwldLink = document.createElement("a");
    let url = URL.createObjectURL(blob);
    let isSafariBrowser = navigator.userAgent.indexOf('Safari') != -1 && navigator.userAgent.indexOf('Chrome') == -1;
    if (isSafariBrowser) {  //if Safari open in new window to save file with random filename.
        dwldLink.setAttribute("target", "_blank");
    }
    dwldLink.setAttribute("href", url);
    dwldLink.setAttribute("download", filename + ".csv");
    dwldLink.style.visibility = "hidden";
    document.body.appendChild(dwldLink);
    dwldLink.click();
    document.body.removeChild(dwldLink);
  }

  CheckSearchCondition(){
    if(!this.ListDataReportCondition.MONTH?false:true){
      if(!this.ListDataReportCondition.YEAR?true:false){
        //console.log(this.ListDataReportCondition.YEAR);
        this.modal.warning("Must input Year of Month.",this.viewref,null);
        return false;
      }
    }
    return true;
  }//end CheckSearchCondition

  onChangeMonth() {
    console.log("OnChange: " + this.ListDataReportCondition.MONTH);
    console.log("OnChange: " + this.ListDataReportCondition.MONTH.toString().length);
    if (this.ListDataReportCondition.MONTH.toString().length > 2) {
      this.ListDataReportCondition.MONTH = Number(this.ListDataReportCondition.MONTH.toString().substring(0,2));
      return false;
    }
  }

  onChangeYear() {
    console.log("OnChange: " + this.ListDataReportCondition.YEAR);
    console.log("OnChange: " + this.ListDataReportCondition.YEAR.toString().length);
    if (this.ListDataReportCondition.YEAR.toString().length > 4) {
      this.ListDataReportCondition.YEAR = Number(this.ListDataReportCondition.YEAR.toString().substring(0,4));
      return false;
    }
  }

  //Load Staff info to label
  onChangeStaffID(){
    //console.log("OnChange: "+this.ListDataReportCondition.STAFF_ID); 
    if(!this.ListDataReportCondition.STAFF_ID){
      //if null || undifind || ""
      this.ListDataReportCondition.STAFF_NAME_EN = null;
      this.ListDataReportCondition.STAFF_NAME_TH = null;
      //return;
    }
    this.HttpService.get('IC', 'SNSD172_F_Get_Staff_Name', this.ListDataReportCondition.STAFF_ID )
      .subscribe(res => {
        if(!res.Table[0]){          
          this.ListDataReportCondition.STAFF_NAME_EN = null;
          this.ListDataReportCondition.STAFF_NAME_TH = null;
        }else{
          this.ListDataReportCondition.STAFF_NAME_EN = res.Table[0].STAFF_NAME_EN;
          this.ListDataReportCondition.STAFF_NAME_TH = res.Table[0].STAFF_NAME_TH;
        }        
      });
  }


}

//for Column of Data set (Report Viewer)
// export interface PeriodicElement {
    
// COMPANY_CODE: string ; 
// GROUP_PART_NO: string ; 
// VENDOR_CODE: string; 
// VENDOR_TYPE: string; 
// ONLINE_FLAG: string; 
// PART_CATEGORY: number; 
// ORDER_QTY_EDF: number; 
// SUGGEST_STATUS: string; 
// PO_PROCESS_DATE: Date; 
// ORDER_QTY_MANUA: number; 
// ORDER_STATUS: string; 
// ORDER_QTY_N_01: number; 
// ORDER_QTY_N_02: number; 
// ORDER_QTY_N_03: number; 
// ORDER_QTY_N_04: number; 
// ORDER_QTY_N_05: number; 
// ORDER_QTY_N_06: number; 
// ORDER_QTY_N_07: number; 
// ORDER_QTY_N_08: number; 
// ORDER_QTY_N_09: number; 
// ORDER_QTY_N_10: number; 
// ORDER_QTY_N_11: number; 
// ORDER_QTY_N_12: number; 
// OH_QTY: number; 
// BO_QTY: number; 
// PO_QTY: number; 
// BASE_PRICE: number; 
// ORDER_SC: number; 
// CREATE_BY: string; 
// CREATE_DATE: Date; 
// LAST_UPD_PGM: string; 
// LAST_UPD_BY: string; 
// LAST_UPD_DATE: Date; 
// ATTRIBUTE01: string; 
// ATTRIBUTE02: string; 
// ATTRIBUTE03: string; 
// ATTRIBUTE04: string; 
// ATTRIBUTE05: string;
// }

