import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snm020p',
  templateUrl: './snm020p.component.html',
  styleUrls: ['./snm020p.component.css']
})


export class SNM020PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public ParamSearch: any = {};
  public Params: any = {};
  public ParamEdit: any = {};
  public ParamAdd: any = {};
  public categoryList: any = [];
  public tabledata: any = [];
  public isAdd: boolean = false;
  

  public ConfigCategory: any = {
    ColName: "DESCRIPT_CODE",
    ColValue: "",
    PlaceholderText: "Select Description Code",
    SourceController: "TI",
    SourceMethodName: "SNM020P_GetDESCRIPT",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public SetSelectedDescriptCode(value: any) {
    this.ParamSearch.DESCRIPT_CODE = value.DESCRIPT_CODE;
    this.ParamSearch.DESCRIPT_NAME = value.DESCRIPT_NAME;
  }

  public hideCols: Array<string> = [];
  DescriptCodeControl = new FormControl('', [Validators.required])

  public ngOnInit() {
    this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
    this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
  }

  public Search() {
    this.tabledata = [];
    this.http.post("TI", "SNM020P_GetDescriptionCode", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }

  public Add() {
    this.DescriptCodeControl.reset();
    //this.ParamAdd = {};
    //this.isAdd = true
    this.dialogAdd.OpenDialog();
  }

  public SaveAdd() {
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
  }


  public ConfirmSave = () => {
    this.http.post('TI', 'SNM020P_Insert', this.ParamAdd)
      .subscribe(res => {
 
          if (res.Table[0].STATUS == 'Done') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            this.Search();
            this.ParamAdd = this.global.ClearObject(this.ParamAdd);
            this.dialogAdd.Close();

          } else if (res.Table[0].STATUS == 'Duplicate') {
            this.modal.warning('No change to save. Found duplicate record.', this.viewref);
          }
          else {
            this.modal.error('No change to save. Something went wrong.', this.viewref);
          }
        
      })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.DescriptCodeControl.reset();
    this.isAdd = false;
    this.ParamEdit = data;

    //console.log('data : ', data);
    this.dialogEdit.OpenDialog();
  }

  public SaveEdit() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmEdit)
  }

  public ConfirmEdit = () => {

    this.http.post('TI', 'SNM020P_Update', this.ParamEdit)
      .subscribe(res => {
        console.log(res)
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialogEdit.Close();
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

  public CancleEdit() {
    this.dialogEdit.Close();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }

  public ConfirmDelete = data => {

    this.http.post('TI', 'SNM020P_Delete', data)
      .subscribe(res => {

        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          console.log(res)
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })

  }



}

