import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';



@Component({
  selector: 'snm023p',
  templateUrl: './snm023p.component.html',
  styleUrls: ['./snm023p.component.css']
})



export class SNM023PComponent implements OnInit {

  public params: any = {};

  public Data: any = {
    COMPANY_CODE: null,
    PART_CODE: null,
    PART_NAME: null,
    DIMENSION_MAX: null,
    DIMENSION_MID: null,
    DIMENSION_MIN: null,
    DESCRIPTION_CODE: null,
    TARIFF_CODE: null,
    PACKAGING_CODE: null,
    EXPENSIVE_CODE: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    LAST_IP_ADDR: null,
    LAST_UPD_PGM: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    LAST_UPD_NAME: null
  };

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }

  @ViewChild("dialogMain", { static: false }) dialogMain: any;
  @ViewChild("dialogReport", { static: false }) dialogReport: any;

  public MainDatatable: any = [];
  public FrmTitle: any;
  public IsEdit: any = true;

  public lookupPartCodeConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part Code",
    SourceController: "wPMS",
    SourceMethodName: "GetPartCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupDescriptionCodeConfig: any = {
    ColName: "LOOKUP_DESCRIPT_CODE",
    PlaceholderText: "Select Description Code",
    SourceController: "WH",
    SourceMethodName: "GetDescriptCode",
    NoOfShowRecords: 100,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public lookupTariffCodeConfig: any = {
    ColName: "TARIFF_CODE",
    PlaceholderText: "Select Tariff Code",
    SourceController: "WH",
    SourceMethodName: "GetTariffCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0
  }

  public lookupExpensiveCodeConfig: any = {
    ColName: "EXPENSIVE_CODE",
    PlaceholderText: "Select Expensive Code",
    SourceController: "WH",
    SourceMethodName: "GetExpensiveCode",
    NoOfShowRecords: 10,
    MinLengthSearch: 0
  }

  ngOnInit() {
  }

  Search = () => {
    this.http.post('WH', 'SNM023P_GetData', this.params)
      .subscribe(res => {
        this.MainDatatable = res.Table;
      })
  }

  InitData() {
    this.Data = {};
  }

  CreateClick() {
    this.InitData();
    this.FrmTitle = "New Part Code";
    this.IsEdit = false;
    this.dialogMain.OpenDialog();
  }

  EditClick(row) {
    this.InitData();
    this.IsEdit = true;
    this.FrmTitle = "Edit Part Code";
    this.Data = row;
    this.dialogMain.OpenDialog();
  }

  ConfirmDelete(row) {
    this.Data = row
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.Delete);
  }

  Delete = () => {
    this.http.post('WH', 'SNM023P_PartCode_Delete', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.Search();
          this.params.PART_CODE = null;
          this.params.PART_NAME = null;
        }
      });
  }

  ConfirmSave() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
  }

  Save = () => {
    this.http.post('WH', 'SNM023P_PartCode_Save', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  Cancel() {
    this.InitData();
    this.dialogMain.Close();
  }

  public SetSelectedPartCode(value: any) {
    this.params.PART_CODE = value.PART_CODE;
    this.params.PART_NAME = value.PART_NAME_TH
    this.params.PART_CODE_S = value.PART_CODE;
    this.params.PART_CODE_E = value.PART_CODE;
    this.Search()
  }

  public SetSelectedPartCodeStart(value: any) {
    this.params.PART_CODE_S = value.PART_CODE;
  }

  public SetSelectedPartCodeEnd(value: any) {
    this.params.PART_CODE_E = value.PART_CODE;
  }

  public SetSelectedDescriptionCode(value: any) {
    this.Data.DESCRIPTION_CODE = value.DESCRIPT_CODE;
  }

  public SetSelectedTariffCode(value: any) {
    this.Data.TARIFF_CODE = value.TARIFF_CODE;
  }

  public SetSelectedExpensiveCode(value: any) {
    this.Data.EXPENSIVE_CODE = value.EXPENSIVE_CODE;
  }

  ExportExcel() {
    this.http.Download('WH', 'SNSQ023_getData_Export', JSON.stringify(this.params))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
        } else {
          this.modal.error('Download not complete', this.viewref)
        }
      })
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNM023P.csv";
    a.click();
  }

  public OpenReport() {
    this.dialogReport.OpenDialog();
  }

  public CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    if (this.params.PART_CODE_S && this.params.PART_CODE_E) {
      this.global.GoToReport("PMS_RPT_SALES_SNM023R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PART_CODE_S: this.params.PART_CODE_S,
        P_PART_CODE_E: this.params.PART_CODE_E,

      })
    }
    else {
      this.modal.warning("Please fill Part Code", this.viewref);
    }
  }
}

