import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { MatDialog } from '@angular/material/dialog';
import { DialogComponent } from '../../../components/shared/dialog/dialog.component';
import { ModalService } from '../../../core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';
import { Globals } from 'src/app/core/global';
import { ActivatedRoute } from '@angular/router';

@Component({
    selector: 'snm042p',
    templateUrl: './snm042p.component.html',
    styleUrls: ['./snm042p.component.css']
})

export class SNM042PComponent implements OnInit {

    constructor(
        private http: HttpService,
        public dialog: MatDialog,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals,
        private route: ActivatedRoute
    ) {
    }

    @ViewChild("dialogEditTarriff") dialogEditTarriff: any
    @ViewChild("dialogAddTarriff") dialogAddTarriff: any
    public dataList: any = [];
    public tariffList: any = [];
    public MTtariffList: any = [];
    public formData: any = { TariffCode: '' };
    public index: any;
    public DutyLate: any;
    public data: any = {};
    public UpdateBy: string;
    public UpdateDate: any;
    public tariffDetail: any;

    public lookupConfigTariff: any = {
        ColName: "TARIFF_TEXT",
        ColValue: "TARIFF_CODE",
        PlaceholderText: "Select Tariff Code",
        SourceController: "IC",
        SourceMethodName: "SNM042P_GetTariffCode",
        NoOfShowRecords: 50,
        MinLengthSearch: 2
    }

    ngOnInit() {
        this.GetTariffData();
    }

    GetTariffData() {
        this.dataList = [];
        this.http.post("IC", "SNM042P_GetTariff_SEARCH", JSON.stringify(this.formData))
            .subscribe((result: any) => {
                this.dataList = result.Table;
            })
    }

    keyDownFunction(event) {
        if (event.keyCode == 13) {
            this.GetTariffData();
        }
    }

    SetTariffLookup(v) {
        this.formData.TariffCode = v;
    }

    editRow(row: any, index: any) {

        // this.index = index;

        // this.DutyLate = cloneDeep(row.DUTY_RATE);
        // this.UpdateBy = row.UPDATE_BY;
        // this.UpdateDate = row.UPDATE_DATE;

        this.tariffDetail = cloneDeep(row);
        this.dialogEditTarriff.OpenDialog();
    }

    SaveDataEdit() {
        this.modal.confirm("Do you want to save your change?", this.viewref,
            () => {
                this.http.post('IC', 'SNM042P_SaveTariff', this.tariffDetail)
                    .subscribe(res => {
                        if (res === "Done") {
                            this.modal.info('Save successfully', this.viewref)
                            this.GetTariffData();
                            this.dialogEditTarriff.Close();
                        }
                    }, (err) => {
                        console.log(err, 'err')
                    })
            }, () => { })
    }

    AddTariffCode() {
        this.data = {};
        this.dialogAddTarriff.OpenDialog();
    }

    SaveDataAdd() {
        this.modal.confirm("Do you want to save your change?", this.viewref,
            () => {
                this.http.post('IC', 'SNM042P_SaveAdd_MT_TariffCode', this.data)
                    .subscribe(res => {
                        if (res === "Done") {
                            this.modal.info('Save successfully', this.viewref)
                            this.GetTariffData();
                            this.dialogAddTarriff.Close();
                        }
                    }, (err) => {
                        console.log(err, 'err')
                    })
            }, () => { })
    }

}
