import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';


@Component({
  selector: 'snm049p',
  templateUrl: './snm049p.component.html',
  styleUrls: ['./snm049p.component.css']
})



export class SNM049PComponent implements OnInit {

  public params = {
    COUNTRY_CODE: null,
    COUNTRY_NAME: null
  }

  public Data: any = {
    COMPANY_CODE: null,
    COUNTRY_CODE: null,
    COUNTRY_NAME_EN: null,
    COUNTRY_NAME_TH: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    CREATE_BY_NAME: null,
    LAST_UPD_PGM: null,
    LAST_IP_ADDR: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    UPDATE_BY_NAME: null,
  };

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }

  @ViewChild("dialogMain", { static: false }) dialogMain: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public tableData: any = [];
  public FrmTitle: any;
  public IsEdit: any = true;

  public lookupCountryCodeConfig: any = {
    ColName: "LOOKUP_COUNTRY_CODE",
    PlaceholderText: "Select Country Code",
    SourceController: "IC",
    SourceMethodName: "SNM049P_GetCountryCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  SetSelectedCountryCode(value: any) {
    this.params.COUNTRY_CODE = value.COUNTRY_CODE;
    this.params.COUNTRY_NAME = value.COUNTRY_NAME;
  };

  ngOnInit() {
    this.Search()
  }

  Search = () => {
    this.http.post('IC', 'SNM049P_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      })
  }

  InitData() {
    this.Data = {};
  }

  CreateClick() {
    this.FrmTitle = "New Country Code";
    this.InitData();
    this.IsEdit = false;
    this.dialogMain.OpenDialog();
  }

  EditClick(row) {
    this.FrmTitle = "Edit Country Code";
    this.InitData();
    this.Data = row;
    this.IsEdit = true;
    this.dialogEdit.OpenDialog();
  }

  ConfirmDelete(row) {
    this.Data = row;
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.Delete);
  }

  Delete = () => {
    this.http.post('IC', 'SNM049P_Delete', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.Search();
          this.params.COUNTRY_CODE = null;
          this.params.COUNTRY_NAME = null;
        }
      });
  }

  ConfirmSave() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
  }

  Save = () => {
    this.http.post('IC', 'SNM049P_Update', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  CancelMain() {
    this.InitData();
    this.dialogMain.Close();

  }

  CancelEdit() {
    this.InitData();
    this.dialogEdit.Close();
  }
}

