import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';


@Component({
  selector: 'SNM121P',
  templateUrl: './SNM121P.component.html',
  styleUrls: ['./SNM121P.component.css']
})



export class SNM121PComponent implements OnInit {

  public params: any = {}
  public Data: any = {};
  public Datatable: any = [];

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }

  @ViewChild("dialogMain", { static: false }) dialogMain: any;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNM121P_GetCustomer",
    NoOfShowRecords: 50,
    MinLengthSearch: 0
  }

  public SetSelectedCustomerCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUSTOMER_NAME;
  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNM121P_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(value: any) {
    this.params.ORDER_NO = value.ORDER_NO;
  }

  public lookupCustomerCodeMasterConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNM121P_GetCustomer2",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerMasterCode(value: any) {
    this.Data.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.Data.CUSTOMER_NAME = value.CUSTOMER_NAME;
  }

  ngOnInit() {
    this.Search();
  }

  Search = () => {
    this.http.post('SL', 'SNM121P_GetData', this.params)
      .subscribe(res => {
        this.Datatable = res.Table;
      })
  }

  InitData() {
    this.Data = {};
  }

  CreateClick() {
    this.InitData();
    this.dialogMain.OpenDialog();
  }

  ConfirmDelete(row) {
    this.Data = {};
    this.Data = row
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.Delete);
  }

  Delete = () => {
    this.http.post('SL', 'SNM121P_Delete', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.Search();
        }
      });
  }

  ConfirmSave() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
  }

  Save = () => {
    this.http.post('SL', 'SNM121P_Save', this.Data)
      .subscribe(res => {
        console.log(res)
        if (res.Table[0].STATUS == 'DONE') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  Cancel() {
    this.InitData();
    this.dialogMain.Close();
  }
}

