import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snm110p',
    templateUrl: './SNM110P.component.html',
    styleUrls: ['./SNM110P.component.css']
})

export class SNM110PComponent implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private modal: ModalService,
        private viewref: ViewContainerRef
    ) { }

    public Category: string;
    public SubCategory: string;
    public LocationFrom: string;
    public LocationTo: string;
    public CategoryList: Array<any> = [];
    public OverlapList: Array<any> = [];
    public formData: any = {};

    public viewMode: boolean = false;

    @ViewChild("dialog") dialog: DialogTemplateComponent;

    ngOnInit() {

    }

    GetData() {
        this.CategoryList = [];
        this.http.get("WH", "SNM110P_GetCategory", this.Category || "null")
            .subscribe(result => {
                this.CategoryList = result.Table;
            });
    }

    ViewCategoryLocation(data) {
        this.viewMode = true;
        this.formData = data;
        this.OverlapList = [];
        this.dialog.OpenDialog();
    }


    AddCategoryLocation() {
        this.viewMode = false;
        this.formData = {};
        this.OverlapList = [];
        this.dialog.OpenDialog();
    }

    CheckOverlapLocation() {
        const {
            MAIN_CATEGORY
            , SUB_CATEGORY
            , FROM_LOCATION
            , TO_LOCATION
        } = this.formData;

        if (MAIN_CATEGORY && SUB_CATEGORY && FROM_LOCATION && TO_LOCATION) {
            this.OverlapList = []
            this.http.get("WH", "SNM110P_GetOverlapLocation", MAIN_CATEGORY, SUB_CATEGORY, FROM_LOCATION, TO_LOCATION)
                .subscribe(result => {
                    this.OverlapList = result.Table;
                })
        } else {
            this.modal.error("Please input required (*) items !", this.viewref);
        }
    }

    SaveCategoryLocation() {
        const {
            MAIN_CATEGORY
            , SUB_CATEGORY
            , FROM_LOCATION
            , TO_LOCATION
        } = this.formData;

        if (MAIN_CATEGORY && SUB_CATEGORY && FROM_LOCATION && TO_LOCATION) {
            this.modal.confirm("Are you sure to <u><b>ADD</b></u> this category location?", this.viewref
                , () => {
                    this.OverlapList = []
                    this.http.post("WH", ["SNM110P_AddCategoryLocation", MAIN_CATEGORY, SUB_CATEGORY, FROM_LOCATION, TO_LOCATION], null)
                        .subscribe(result => {
                            this.GetData();
                            this.modal.info("Add Category Location Successfully.", this.viewref);
                            this.dialog.Close();
                        })
                }, () => { })
        } else {
            this.modal.error("Please input required (*) items !", this.viewref);
        }
    }

    DeleteCategoryLocation() {
        const {
            MAIN_CATEGORY
            , SUB_CATEGORY
            , FROM_LOCATION
            , TO_LOCATION
        } = this.formData;

        if (MAIN_CATEGORY && SUB_CATEGORY && FROM_LOCATION && TO_LOCATION) {
            this.modal.confirm("Are you sure to <u><b>DELETE</b></u> this category location?", this.viewref
                , () => {
                    this.OverlapList = []
                    this.http.post("WH", ["SNM110P_DeleteCategoryLocation", MAIN_CATEGORY, SUB_CATEGORY, FROM_LOCATION, TO_LOCATION], null)
                        .subscribe(result => {
                            this.GetData();
                            this.modal.info("Delete Category Location Successfully.", this.viewref);
                            this.dialog.Close();
                        })
                }, () => { })
        } else {
            this.modal.error("Something wrong!, unable to delete this category.", this.viewref);
        }
    }


}


