import { Component, OnInit, Input, Output, EventEmitter, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { FormGroup, FormControl, FormBuilder } from '@angular/forms'
import { Router, ActivatedRoute } from '@angular/router';
import { MatDatepickerInputEvent } from '@angular/material/datepicker';
import { ModalService } from '../../../core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snpp105',
  templateUrl: './SNPP105.component.html',
  styleUrls: ['./SNPP105.component.css']
})



export class SNPP105Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute
  ) {

  }

  public param = {

    ETD_DATE: null,
    ETP_DATE: null,
    INVOICE_NO: null,
    VENDOR_CODE: null,
    PO_NO1: null,
    GROUP_OPTION: '1',
    PO_NO2: null,
    PART_NO: null
  }

  public result: any = [];
  public showProgressBar: boolean = false;
  public ConfigVendor: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    ColValue: "VENDOR_CODE",
    PlaceholderText: "Select Vendor Code",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCodeByInvoice",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    SourceParams: {},
    UpperCase: true
  }


  public ConfigInvoice: any = {
    ColName: "INVOICE_NO",
    ColValue: "INVOICE_NO",
    PlaceholderText: "Select Invoice No.",
    SourceController: "IC",
    SourceMethodName: "SNPP105_GetInvoiceByVendor",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    SourceParams: {}
  }


  public ConfigPo: any = {
    ColName: "PO_NO",
    ColValue: "PO_NO",
    PlaceholderText: "Select PO No",
    SourceController: "wPMS",
    SourceMethodName: "GetPONo",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    UpperCase: true
  }

  public ConfigPo2: any = {
    ColName: "PO_NO",
    ColValue: "PO_NO",
    PlaceholderText: "Select PO No2",
    SourceController: "wPMS",
    SourceMethodName: "GetPONoByPart",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    SourceParams: {},
    UpperCase: true
  }

  public ConfigPart: any = {
    ColName: "LOOKUP_PART_NAME",
    ColValue: "PART_NO",
    PlaceholderText: "Select Part No",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNoByPO",
    NoOfShowRecords: 50,
    MinLengthSearch: 5,
    SourceParams: {},
    UpperCase: true
  }




  public vendorCode: any
  private loaded: boolean = false;
  public ETD_DATE: any;
  public ETP_DATE: any;
  public validate: boolean = true;
  public currentDate: Date = new Date();

  ngOnInit() {

    this.loaded = true;


  }

  SetVendorCodeLookup(value) {
    this.param.VENDOR_CODE = value;
    this.ConfigInvoice.SourceParams.VENDOR_CODE = value;
  }

  Save() {
    this.modal.confirm('Do you want to update record?', this.viewref, this.Commit);
  }

  Commit = () => {

    let data = {
      INVOICE_NO: this.param.INVOICE_NO,
      VENDOR_CODE: this.param.VENDOR_CODE,
      PO_NO1: this.param.PO_NO1,
      GROUP_OPTION: this.param.GROUP_OPTION,
      PO_NO2: this.param.PO_NO2,
      PART_NO: this.param.PART_NO,
      V_ETD_DATE: this.SetFormateDate(this.result.ETD_DATE),
      V_ETP_DATE: this.SetFormateDate(this.result.ETP_DATE),
      V_ETA_EO_BKK_DATE: this.SetFormateDate(this.result.ETA_EO_BKK_DATE),
      V_ETA_EO_UPC_DATE: this.SetFormateDate(this.result.ETA_EO_UPC_DATE),
      V_ETA_RO_BKK_DATE: this.SetFormateDate(this.result.ETA_RO_BKK_DATE),
      V_ETA_RO_UPC_DATE: this.SetFormateDate(this.result.ETA_RO_UPC_DATE)

    }

    this.http.post('IC', 'SNPP105_SaveNew', data)
      .subscribe(res => {
  
        if (res)
          this.modal.info('Process Complete.', this.viewref);

      }, (err) => {

        var errorMessage = err.error.ExceptionMessage.split('\n')[0].replace('ORA-20001: ', '');
        this.modal.error(errorMessage, this.viewref);
      })
  }


  DateChange(type: string, event: MatDatepickerInputEvent<Date>) {

    if (type == 'ETD') {

      this.param.ETD_DATE = this.SetFormateDate(event.value);
      this.param.ETP_DATE = null
      this.CalETD_ETA()
      //let tomorrow  = new Date(event.value)
      //tomorrow.setDate(tomorrow .getDate() + 1);

    } else {

      //let Yesterday = new Date(event.value)
      //Yesterday.setDate(Yesterday.getDate() - 1);
      this.param.ETP_DATE = this.SetFormateDate(event.value);
      this.param.ETD_DATE = null
      this.CalETD_ETA()

    }
  }


  CalETD_ETA() {

    this.showProgressBar = true;

    this.http.post('IC', 'SNPP105_Save', this.param)
      .subscribe(res => {
        console.log('res', res)
        if (res)
          this.result = res.Table[0]
        this.showProgressBar = false;
        this.ETD_DATE = new Date(res.Table[0].ETD_DATE)
        this.ETD_DATE.setDate(this.ETD_DATE.getDate() + 1);
        this.ETP_DATE = new Date(res.Table[0].ETP_DATE)
        this.ETP_DATE.setDate(this.ETP_DATE.getDate() + 1);

      }, (err) => {

        var errorMessage = err.error.ExceptionMessage.split('\n')[0].replace('ORA-20001: ', '');
        this.modal.error(errorMessage, this.viewref);
      })
  }


  Validate() {

    if (this.param.GROUP_OPTION == '1' && !this.param.INVOICE_NO && !this.param.VENDOR_CODE) {
      return true;
    } else if (this.param.GROUP_OPTION == '2' && !this.param.PO_NO1) {
      return true;
    } else if (this.param.GROUP_OPTION == '3' && !this.param.PO_NO2 && !this.param.PART_NO) {
      return true;
    } else {
      return false;
    }

  }

  ClearParam(event) {

    this.result = []
    this.ETD_DATE = null
    this.ETP_DATE = null

    if (event == '1') {
      this.param.PO_NO1 = null
      this.param.PO_NO2 = null
      this.param.PART_NO = null

    } else if (event == '2') {
      this.param.INVOICE_NO = null
      this.param.VENDOR_CODE = null
      this.param.PO_NO2 = null
      this.param.PART_NO = null
    } else {
      this.param.INVOICE_NO = null
      this.param.VENDOR_CODE = null
      this.param.PO_NO1 = null
    }
  }


  SetFormateDate(date) {

    let d = new Date(date)

    let day = d.getDate();
    let newDay = day.toString().length < 2 ? 0 + '' + day.toString() : day.toString();
    let m = d.getMonth() + 1;
    let newMonth = m.toString().length < 2 ? 0 + '' + m.toString() : m.toString();
    let y = d.getFullYear();

    return newDay + '-' + newMonth + '-' + y;
  }
}
